@@ -3,8 +3,7 @@ test_that("estat-census", {
 
   library(dplyr)
 
-  estat_census <- estat(appId = keyring::key_get("estat-api"),
-                        statsDataId = "https://www.e-stat.go.jp/dbview?sid=0003410379")
+  estat_census <- estat(statsDataId = "https://www.e-stat.go.jp/dbview?sid=0003410379")
   expect_s3_class(estat_census, "estat")
 
   estat_census <- estat_census |>
