@@ -2,8 +2,7 @@ test_that("resas-power_for_industry", {
   skip_on_cran()
   library(dplyr)
 
-  X_API_KEY <- keyring::key_get("resas-api")
-  power_for_industry <- resas(X_API_KEY, "https://opendata.resas-portal.go.jp/docs/api/v1/industry/power/forIndustry.html")
+  power_for_industry <- resas(path = "https://opendata.resas-portal.go.jp/docs/api/v1/industry/power/forIndustry.html")
   expect_s3_class(power_for_industry, "resas")
 
   power_for_industry <- power_for_industry |>
@@ -22,8 +21,7 @@ test_that("resas-population_change_rate", {
   skip_on_cran()
   library(dplyr)
 
-  X_API_KEY <- keyring::key_get("resas-api")
-  population_change_rate <- resas(X_API_KEY, "https://opendata.resas-portal.go.jp/docs/api/v1/population/sum/perYear.html")
+  population_change_rate <- resas(path = "https://opendata.resas-portal.go.jp/docs/api/v1/population/sum/perYear.html")
 
   population_change_rate <- population_change_rate |>
     itemise(pref_code = "1") |>
@@ -37,8 +35,7 @@ test_that("resas-partner_docomo_destination", {
   skip_on_cran()
   library(dplyr)
 
-  X_API_KEY <- keyring::key_get("resas-api")
-  partner_docomo_destination <- resas(X_API_KEY, "https://opendata.resas-portal.go.jp/docs/api/v1/partner/docomo/destination.html") |>
+  partner_docomo_destination <- resas(path = "https://opendata.resas-portal.go.jp/docs/api/v1/partner/docomo/destination.html") |>
     itemise(year = "2016",
             month = "01",
             period_of_day = "1",
@@ -58,8 +55,7 @@ test_that("resas-population-society-for_age_class", {
   skip_on_cran()
   library(dplyr)
 
-  X_API_KEY <- keyring::key_get("resas-api")
-  population_society_for_age_class <- resas(X_API_KEY, "https://opendata.resas-portal.go.jp/docs/api/v1/population/society/forAgeClass.html") |>
+  population_society_for_age_class <- resas(path = "https://opendata.resas-portal.go.jp/docs/api/v1/population/society/forAgeClass.html") |>
     itemise(pref_code = "01") |>
     collect()
 
@@ -71,8 +67,7 @@ test_that("agriculture_crops_farmers_age_structure", {
   skip_on_cran()
   library(dplyr)
 
-  X_API_KEY <- keyring::key_get("resas-api")
-  agriculture_crops_farmers_age_structure <- resas(X_API_KEY, "https://opendata.resas-portal.go.jp/docs/api/v1/agriculture/crops/farmersAgeStructure.html") |>
+  agriculture_crops_farmers_age_structure <- resas(path = "https://opendata.resas-portal.go.jp/docs/api/v1/agriculture/crops/farmersAgeStructure.html") |>
     itemise(city_code = "11362",
             farmers_type = "1",
             gender_type = "3",
@@ -88,8 +83,7 @@ test_that("agriculture_crops_farmers_average_age", {
   skip_on_cran()
   library(dplyr)
 
-  X_API_KEY <- keyring::key_get("resas-api")
-  agriculture_crops_farmers_average_age <- resas(X_API_KEY, "https://opendata.resas-portal.go.jp/docs/api/v1/agriculture/crops/farmersAverageAge.html") |>
+  agriculture_crops_farmers_average_age <- resas(path = "https://opendata.resas-portal.go.jp/docs/api/v1/agriculture/crops/farmersAverageAge.html") |>
     itemise(city_code = "11362",
             farmers_type = "1",
             gender_type = "3",
@@ -104,8 +98,7 @@ test_that("prefectures", {
   skip_on_cran()
   library(dplyr)
 
-  X_API_KEY <- keyring::key_get("resas-api")
-  prefectures <- resas(X_API_KEY, "https://opendata.resas-portal.go.jp/docs/api/v1/prefectures.html")
+  prefectures <- resas(path = "https://opendata.resas-portal.go.jp/docs/api/v1/prefectures.html")
 
   expect_s3_class(prefectures, "tbl_df")
 })
@@ -114,8 +107,7 @@ test_that("medical_welfare_care_analysis_chart", {
   skip_on_cran()
   library(dplyr)
 
-  X_API_KEY <- keyring::key_get("resas-api")
-  medical_welfare_care_analysis_chart <- resas(X_API_KEY, "https://opendata.resas-portal.go.jp/docs/api/v1/medicalWelfare/careAnalysis/chart.html",
+  medical_welfare_care_analysis_chart <- resas(path = "https://opendata.resas-portal.go.jp/docs/api/v1/medicalWelfare/careAnalysis/chart.html",
                                                query = list(matter_1 = "1")) |>
     itemise(year = "2015",
             disp_type = "1",
